@@ -25,84 +25,49 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-#include "ebml/ebml.h"
-#include "ebml/ebml_internal.h"
-#if defined(EBML_LIBRARY)
-# if defined(EBML_LEGACY_API)
-#  include "ebml2_legacy_project.h"
-# else
-#  include "ebml2_project.h"
-# endif
-#endif
+#include "ebml2/ebml.h"
+#include "internal.h"
 
-extern const nodemeta BufStream_Class[];
-extern const nodemeta MemStream_Class[];
-extern const nodemeta Streams_Class[];
-#if defined(CONFIG_EBML_UNICODE)
-extern const nodemeta LangStr_Class[];
-extern const nodemeta UrlPart_Class[];
-# if defined(CONFIG_STDIO)
-extern const nodemeta Stdio_Class[];
-# endif
-#endif
-
-extern const nodemeta EBMLElement_Class[];
-extern const nodemeta EBMLMaster_Class[];
-extern const nodemeta EBMLBinary_Class[];
-extern const nodemeta EBMLString_Class[];
-extern const nodemeta EBMLInteger_Class[];
-extern const nodemeta EBMLCRC_Class[];
-extern const nodemeta EBMLDate_Class[];
-extern const nodemeta EBMLVoid_Class[];
-
-err_t EBML_Init(nodecontext *p)
+err_t EBML_Init(parsercontext *p)
 {
-    // TODO: only when used as standalone (no coremake & core-c in the rest of the project)
-#if defined(EBML_LIBRARY)
-    tchar_t LibName[MAXPATH];
-    tcscpy_s(LibName,TSIZEOF(LibName),PROJECT_NAME T(" v") PROJECT_VERSION);
-    Node_SetData(p,CONTEXT_LIBEBML_VERSION,TYPE_STRING,LibName);
-#endif
+    Node_SetData(p,CONTEXT_LIBEBML_VERSION,TYPE_STRING,T("libebml2 v") LIBEBML2_PROJECT_VERSION);
 
-    NodeRegisterClassEx((nodemodule*)p,BufStream_Class);
-	NodeRegisterClassEx((nodemodule*)p,MemStream_Class);
-	NodeRegisterClassEx((nodemodule*)p,Streams_Class);
-#if defined(CONFIG_EBML_UNICODE)
-	NodeRegisterClassEx((nodemodule*)p,LangStr_Class);
-	NodeRegisterClassEx((nodemodule*)p,UrlPart_Class);
-# if defined(CONFIG_STDIO)
-	NodeRegisterClassEx((nodemodule*)p,Stdio_Class);
-# endif
-#endif
-
-    NodeRegisterClassEx((nodemodule*)p,EBMLElement_Class);
-	NodeRegisterClassEx((nodemodule*)p,EBMLMaster_Class);
-	NodeRegisterClassEx((nodemodule*)p,EBMLBinary_Class);
-	NodeRegisterClassEx((nodemodule*)p,EBMLString_Class);
-	NodeRegisterClassEx((nodemodule*)p,EBMLInteger_Class);
-	NodeRegisterClassEx((nodemodule*)p,EBMLDate_Class);
-	NodeRegisterClassEx((nodemodule*)p,EBMLCRC_Class);
-	NodeRegisterClassEx((nodemodule*)p,EBMLVoid_Class);
+    NodeRegisterClassEx(&p->Base.Base,EBMLElement_Class);
+	NodeRegisterClassEx(&p->Base.Base,EBMLMaster_Class);
+	NodeRegisterClassEx(&p->Base.Base,EBMLBinary_Class);
+	NodeRegisterClassEx(&p->Base.Base,EBMLString_Class);
+	NodeRegisterClassEx(&p->Base.Base,EBMLInteger_Class);
+	NodeRegisterClassEx(&p->Base.Base,EBMLDate_Class);
+	NodeRegisterClassEx(&p->Base.Base,EBMLCRC_Class);
+	NodeRegisterClassEx(&p->Base.Base,EBMLVoid_Class);
 
     return ERR_NONE;
 }
 
-err_t EBML_Done(nodecontext *p)
+void EBML_Done(parsercontext *p)
 {
-    return ERR_NONE;
 }
 
-CONTEXT_CONST ebml_context EBML_ContextDummy = {0xFF, EBML_DUMMY_ID, 0, 0, "DummyElement", NULL, NULL};
+static CONTEXT_CONST ebml_context EBML_ContextDummy = {0xFF, EBML_DUMMY_ID, 0, 0, "DummyElement", NULL, NULL};
 
-CONTEXT_CONST ebml_context EBML_ContextVersion            = {0x4286, EBML_INTEGER_CLASS, 1, EBML_MAX_VERSION, "EBMLVersion", NULL, EBML_SemanticGlobals};
-CONTEXT_CONST ebml_context EBML_ContextReadVersion        = {0x42F7, EBML_INTEGER_CLASS, 1, EBML_MAX_VERSION, "EBMLReadVersion", NULL, EBML_SemanticGlobals};
-CONTEXT_CONST ebml_context EBML_ContextMaxIdLength        = {0x42F2, EBML_INTEGER_CLASS, 1, EBML_MAX_ID, "EBMLMaxIdLength", NULL, EBML_SemanticGlobals};
-CONTEXT_CONST ebml_context EBML_ContextMaxSizeLength      = {0x42F3, EBML_INTEGER_CLASS, 1, EBML_MAX_SIZE, "EBMLMaxSizeLength", NULL, EBML_SemanticGlobals};
-CONTEXT_CONST ebml_context EBML_ContextDocType            = {0x4282, EBML_STRING_CLASS,  1, (intptr_t)"matroska", "EBMLDocType", NULL, EBML_SemanticGlobals};
-CONTEXT_CONST ebml_context EBML_ContextDocTypeVersion     = {0x4287, EBML_INTEGER_CLASS, 1, 1, "EBMLDocTypeVersion", NULL, EBML_SemanticGlobals};
-CONTEXT_CONST ebml_context EBML_ContextDocTypeReadVersion = {0x4285, EBML_INTEGER_CLASS, 1, 1, "EBMLDocTypeReadVersion", NULL, EBML_SemanticGlobals}; 
+static CONTEXT_CONST ebml_context EBML_ContextEbmlVoid   = {0xEC, EBML_VOID_CLASS, 0, 0, "EBMLVoid", NULL, NULL};
+static CONTEXT_CONST ebml_context EBML_ContextEbmlCrc32  = {0xBF, EBML_CRC_CLASS, 0, 0, "EBMLCrc32", NULL, NULL};
 
-static const ebml_semantic EBML_SemanticHead[] = {
+static const ebml_semantic EBML_SemanticGlobals[] = {
+    {0, 0, &EBML_ContextEbmlVoid},
+    {0, 1, &EBML_ContextEbmlCrc32},
+    {0, 0, NULL} // end of the table
+};
+
+static CONTEXT_CONST ebml_context EBML_ContextVersion            = {0x4286, EBML_INTEGER_CLASS, 1, EBML_MAX_VERSION, "EBMLVersion", NULL, EBML_SemanticGlobals};
+static CONTEXT_CONST ebml_context EBML_ContextReadVersion        = {0x42F7, EBML_INTEGER_CLASS, 1, EBML_MAX_VERSION, "EBMLReadVersion", NULL, EBML_SemanticGlobals};
+static CONTEXT_CONST ebml_context EBML_ContextMaxIdLength        = {0x42F2, EBML_INTEGER_CLASS, 1, EBML_MAX_ID, "EBMLMaxIdLength", NULL, EBML_SemanticGlobals};
+static CONTEXT_CONST ebml_context EBML_ContextMaxSizeLength      = {0x42F3, EBML_INTEGER_CLASS, 1, EBML_MAX_SIZE, "EBMLMaxSizeLength", NULL, EBML_SemanticGlobals};
+static CONTEXT_CONST ebml_context EBML_ContextDocType            = {0x4282, EBML_STRING_CLASS,  1, (intptr_t)"matroska", "EBMLDocType", NULL, EBML_SemanticGlobals};
+static CONTEXT_CONST ebml_context EBML_ContextDocTypeVersion     = {0x4287, EBML_INTEGER_CLASS, 1, 1, "EBMLDocTypeVersion", NULL, EBML_SemanticGlobals};
+static CONTEXT_CONST ebml_context EBML_ContextDocTypeReadVersion = {0x4285, EBML_INTEGER_CLASS, 1, 1, "EBMLDocTypeReadVersion", NULL, EBML_SemanticGlobals}; 
+
+static CONTEXT_CONST ebml_semantic EBML_SemanticHead[] = {
     {1, 1, &EBML_ContextVersion},
     {1, 1, &EBML_ContextReadVersion},
     {1, 1, &EBML_ContextMaxIdLength},
@@ -112,19 +77,60 @@ static const ebml_semantic EBML_SemanticHead[] = {
     {1, 1, &EBML_ContextDocTypeReadVersion},
     {0, 0, NULL} // end of the table
 };
-CONTEXT_CONST ebml_context EBML_ContextHead = {0x1A45DFA3, EBML_MASTER_CLASS, 0, 0, "EBMLHead\0mfthis", EBML_SemanticHead, EBML_SemanticGlobals};
+static CONTEXT_CONST ebml_context EBML_ContextHead = {0x1A45DFA3, EBML_MASTER_CLASS, 0, 0, "EBMLHead\0mfthis", EBML_SemanticHead, EBML_SemanticGlobals};
 
 
-CONTEXT_CONST ebml_context EBML_ContextEbmlVoid   = {0xEC, EBML_VOID_CLASS, 0, 0, "EBMLVoid", NULL, NULL};
-CONTEXT_CONST ebml_context EBML_ContextEbmlCrc32  = {0xBF, EBML_CRC_CLASS, 0, 0, "EBMLCrc32", NULL, NULL};
+static CONTEXT_CONST ebml_context EBML_ContextGlobals = {0, 0, 0, 0, "GlobalContext", EBML_SemanticGlobals, EBML_SemanticGlobals};
 
-const ebml_semantic EBML_SemanticGlobals[] = {
-    {0, 0, &EBML_ContextEbmlVoid},
-    {0, 1, &EBML_ContextEbmlCrc32},
-    {0, 0, NULL} // end of the table
-};
+CONTEXT_CONST ebml_context *EBML_getContextHead()
+{
+	return &EBML_ContextHead;
+}
+CONTEXT_CONST ebml_context *EBML_getContextDummy()
+{
+	return &EBML_ContextDummy;
+}
+CONTEXT_CONST ebml_context *EBML_getContextVersion()
+{
+	return &EBML_ContextVersion;
+}
+CONTEXT_CONST ebml_context *EBML_getContextReadVersion()
+{
+	return &EBML_ContextReadVersion;
+}
+CONTEXT_CONST ebml_context *EBML_getContextMaxIdLength()
+{
+	return &EBML_ContextMaxIdLength;
+}
+CONTEXT_CONST ebml_context *EBML_getContextMaxSizeLength()
+{
+	return &EBML_ContextMaxSizeLength;
+}
+CONTEXT_CONST ebml_context *EBML_getContextDocType()
+{
+	return &EBML_ContextDocType;
+}
+CONTEXT_CONST ebml_context *EBML_getContextDocTypeVersion()
+{
+	return &EBML_ContextDocTypeVersion;
+}
+CONTEXT_CONST ebml_context *EBML_getContextDocTypeReadVersion()
+{
+	return &EBML_ContextDocTypeReadVersion;
+}
+CONTEXT_CONST ebml_context *EBML_getContextEbmlVoid()
+{
+	return &EBML_ContextEbmlVoid;
+}
+CONTEXT_CONST ebml_context *EBML_getContextEbmlCrc32()
+{
+	return &EBML_ContextEbmlCrc32;
+}
 
-static const ebml_context EBML_ContextGlobals = {0, 0, 0, 0, "GlobalContext", EBML_SemanticGlobals, EBML_SemanticGlobals};
+const ebml_semantic *EBML_getSemanticGlobals()
+{
+	return EBML_SemanticGlobals;
+}
 
 filepos_t EBML_ReadCodedSizeValue(const uint8_t *InBuffer, size_t *BufferSize, filepos_t *SizeUnknown)
 {
